@@ -2,9 +2,11 @@
 from .btw_code import BtwCode, btw_codes_hoog, btw_codes_laag, btw_codes_geen
 from .in_ex_btw import InExBTW
 from .mutatie_soort import MutatieSoort
+from .bedrijf_particulier import BedrijfParticulier
 
 
 __all__ = [
+    BedrijfParticulier,
     BtwCode,
     btw_codes_hoog,
     btw_codes_laag,
