@@ -2,10 +2,14 @@
 from .mutatie_filter import MutatieFilter
 from .mutatie_regel import MutatieRegel
 from .mutatie import Mutatie
+from .relatie_filter import RelatieFilter
+from .relatie import Relatie
 
 
 __all__ = [
     MutatieFilter,
     MutatieRegel,
     Mutatie,
+    RelatieFilter,
+    Relatie,
 ]
